{***************************************************************
 *
 * Unit Name : Main
 * Purpose   : Text Editor
 * Author    : Eugen Mihailescu
 * Company   : EM Quicksoft Romania SRL
 * Copyright : 1998,2002  All rights reserved.
 * Web Site  : http://www.em-quicksoft.com
 * Support   : support@em-quicksoft.com
 * History   : 03/17/2000
 *
 ****************************************************************}

Unit Main;

Interface

Uses Windows,
  SysUtils,
  Classes,
  Graphics,
  Forms,
  Controls,
  Menus,
  StdCtrls,
  Dialogs,
  Buttons,
  Messages,
  ExtCtrls,
  ComCtrls,
  StdActns,
  ActnList,
  ToolWin,
  ImgList,
  Registry,
  IniFiles;

Type
  TMainForm = Class(TForm)
    MainMenu1: TMainMenu;
    File1: TMenuItem;
    FileNewItem: TMenuItem;
    FileOpenItem: TMenuItem;
    FileCloseItem: TMenuItem;
    Window1: TMenuItem;
    Help1: TMenuItem;
    N1: TMenuItem;
    FileExitItem: TMenuItem;
    WindowCascadeItem: TMenuItem;
    WindowTileItem: TMenuItem;
    WindowArrangeItem: TMenuItem;
    HelpAboutItem: TMenuItem;
    OpenDialog: TOpenDialog;
    FileSaveItem: TMenuItem;
    FileSaveAsItem: TMenuItem;
    Edit1: TMenuItem;
    CutItem: TMenuItem;
    CopyItem: TMenuItem;
    PasteItem: TMenuItem;
    WindowMinimizeItem: TMenuItem;
    StatusBar: TStatusBar;
    ActionList1: TActionList;
    EditCut1: TEditCut;
    EditCopy1: TEditCopy;
    EditPaste1: TEditPaste;
    FileNew1: TAction;
    FileSave1: TAction;
    FileExit1: TAction;
    FileOpen1: TAction;
    FileSaveAs1: TAction;
    WindowCascade1: TWindowCascade;
    WindowTileHorizontal1: TWindowTileHorizontal;
    WindowArrangeAll1: TWindowArrange;
    WindowMinimizeAll1: TWindowMinimizeAll;
    HelpAbout1: TAction;
    FileClose1: TWindowClose;
    WindowTileVertical1: TWindowTileVertical;
    WindowTileItem2: TMenuItem;
    ImageList1: TImageList;
    ControlBar1: TControlBar;
    ToolBar2: TToolBar;
    ToolButton9: TToolButton;
    ToolButton1: TToolButton;
    ToolButton2: TToolButton;
    ToolButton3: TToolButton;
    ToolButton4: TToolButton;
    ToolButton5: TToolButton;
    ToolButton6: TToolButton;
    ToolButton7: TToolButton;
    ToolButton8: TToolButton;
    ToolButton10: TToolButton;
    ToolButton11: TToolButton;
    Procedure FileNew1Execute(Sender: TObject);
    Procedure FileOpen1Execute(Sender: TObject);
    Procedure HelpAbout1Execute(Sender: TObject);
    Procedure FileExit1Execute(Sender: TObject);
    Procedure FormCreate(Sender: TObject);
    Procedure HistoryItemClick(Sender: TObject);
    Procedure FormShow(Sender: TObject);
  private
    { Private declarations }
  public
    { Public declarations }
    Procedure ArangeList(Sender: TObject);
    Procedure ReArangeList(Sender: TObject; FirstItem: String);
    Procedure CreateMDIChild(Const Name: String);
  End;

Var
  MainForm          : TMainForm;
  S                 : Array[1..10] Of String;

Implementation

{$R *.DFM}
{$R OtherIcons.res}
Uses ChildWin,
  About;
//******************* TMainForm.CreateMDIChild *************************

Procedure TMainForm.CreateMDIChild(Const Name: String);
Var
  Child             : TMDIChild;
Begin
  { create a new MDI child window }
  Child := TMDIChild.Create(Application);
  Child.Caption := Name;
  If fileexists(Name) Then Child.Editor.Lines.LoadFromFile(Name);
  Child.PathName := Name;
End;
//******************* TMainForm.FileNew1Execute *************************

Procedure TMainForm.FileNew1Execute(Sender: TObject);
Begin
  CreateMDIChild('NONAME' + IntToStr(MDIChildCount + 1));
End;
//******************* TMainForm.FileOpen1Execute *************************

Procedure TMainForm.FileOpen1Execute(Sender: TObject);
Begin
  If OpenDialog.Execute Then
    Begin
      CreateMDIChild(OpenDialog.FileName);
      RearangeList(Self, '&1 ' + OpenDialog.FileName);
    End;
End;
//******************* TMainForm.HelpAbout1Execute *************************

Procedure TMainForm.HelpAbout1Execute(Sender: TObject);
Begin
  AboutBox := TAboutBox.Create(Self);
  Try
    AboutBox.ShowModal;
  Finally
    AboutBox.Free;
  End;
End;
//******************* TMainForm.FileExit1Execute *************************

Procedure TMainForm.FileExit1Execute(Sender: TObject);
Begin
  Close;
End;
//******************* TMainForm.FormCreate *************************

Procedure TMainForm.FormCreate(Sender: TObject);
Var
  R                 : TRegistry;
Begin
  R := TRegistry.Create;
  Try
    R.RootKey := HKEY_CLASSES_ROOT;
    R.OpenKey('.rom', True);
    R.WriteString('', 'ScalaROMFile');
    R.CloseKey;

    R.RootKey := HKEY_CLASSES_ROOT;
    R.DeleteKey('ScalaROMFile');
    R.OpenKey('ScalaROMFile', True);
    R.WriteString('', 'Scala ROM File');
    R.OpenKey('DefaultIcon', True);
    R.WriteString('', Application.ExeName + ',1');
    R.CloseKey;
    R.RootKey := HKEY_CLASSES_ROOT;
    R.OpenKey('ScalaROMFile\Shell', True);
    R.CloseKey;
    R.RootKey := HKEY_CLASSES_ROOT;
    R.OpenKey('ScalaROMFile\Shell\Open with Eugen Editor', True);
    R.CloseKey;
    R.RootKey := HKEY_CLASSES_ROOT;
    R.OpenKey('ScalaROMFile\Shell\Open with Eugen Editor\Command', True);
    R.WriteString('', ExtractShortPathName(Application.ExeName) + ' "%1"');
  Finally
    R.Free;
  End;
End;
//******************* TMainForm.ArangeList *************************

Procedure TMainForm.ArangeList(Sender: TObject);
Var
  F                 : TIniFile;
  Count, k          : Integer;
  NewItem           : TMenuItem;
Begin
  For k := 7 To File1.Count - 1 Do
    File1.Delete(7);
  NewItem := TMenuItem.Create(Self);
  NewItem.Caption := '-';
  File1.Add(NewItem);
  F := TIniFile.Create(ExtractFilePath(Application.ExeName) + 'Settings.ini');
  Try
    Count := F.ReadInteger('ROMFiles', 'FilesCount', 5);

    For k := 1 To Count Do
      Begin
        NewItem := TMenuItem.Create(Self);
        S[k] := F.ReadString('ROMFiles', 'FILE_' + IntToStr(k), '');
        If (Trim(S[k]) <> '') Then
          Begin
            If k < 10 Then
              NewItem.Caption := '&' + IntToStr(k) + #32 + S[k]
            Else
              NewItem.Caption := IntToStr(k) + #32 + S[k];
            NewItem.OnClick := HistoryItemClick;
            File1.Add(NewItem);
          End;
      End;
  Finally
    F.Free;
  End;
  If File1.Count = 8 Then File1.Delete(7);
End;
//******************* TMainForm.ReArangeList *************************

Procedure TMainForm.ReArangeList(Sender: TObject; FirstItem: String);
Var
  F                 : TIniFile;
  Count, k          : Integer;
  ys, xs, zs        : String;
  Found             : Boolean;
Begin
  F := TIniFile.Create(ExtractFilePath(Application.ExeName) + 'Settings.ini');
  Try
    Count := F.ReadInteger('ROMFiles', 'FilesCount', 5);
    For k := 1 To Count Do
      S[k] := F.ReadString('ROMFiles', 'FILE_' + IntToStr(k), '');
    Found := False;
    For k := 1 To Count Do
      Begin
        ys := Copy(FirstItem, Pos(#32, FirstItem) + 1, Length(FirstItem));
        xs := S[k];
        If xs = ys Then
          Begin
            Found := True;
            zs := S[1];
            S[1] := Copy(FirstItem, Pos(#32, FirstItem) + 1, Length(FirstItem));
            S[k] := zs;
            Break;
          End;
      End;
    If Not Found Then
      Begin
        For k := Count - 1 Downto 1 Do
          S[k + 1] := S[k];
        S[1] := Copy(FirstItem, Pos(#32, FirstItem) + 1, Length(FirstItem));
      End;
    For k := 1 To Count Do
      F.WriteString('ROMFiles', 'FILE_' + IntToStr(k), S[k]);

  Finally
    F.Free;
  End;
  ArangeList(Self);
End;
//******************* TMainForm.HistoryItemClick *************************

Procedure TMainForm.HistoryItemClick(Sender: TObject);
Var
  Item              : TMenuItem;
Begin
  With Sender As TMenuItem Do
    Begin
      Item := TMenuItem.Create(Self);
      Try
        Item := Sender As TMenuItem;
        CreateMDIChild(Copy(Item.Caption, Pos(#32, Item.Caption) + 1, Length(Item.Caption)));
        RearangeList(Self, Item.Caption);
      Finally
        Item.Free;
      End;
    End;
End;
//******************* TMainForm.FormShow *************************

Procedure TMainForm.FormShow(Sender: TObject);
Begin
  ArangeList(Self);
  If ParamStr(1) <> '' Then
    CreateMDIChild(ParamStr(1));
End;

End.

